=========
strontium
=========


.. image:: https://img.shields.io/pypi/v/strontium.svg
        :target: https://pypi.python.org/pypi/strontium

.. image:: https://img.shields.io/travis/Trigram19/strontium.svg
        :target: https://travis-ci.com/Trigram19/strontium

.. image:: https://readthedocs.org/projects/strontium/badge/?version=latest
        :target: https://strontium.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




strontium is a high-level medical imaging resource for deep learning in Python


* Free software: MIT license
* Documentation: https://strontium.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
